@@ -246,12 +246,20 @@ public class ClientAdmin extends JFrame {
 
 	private JLabel jLabel19 = null;
 
-	private JTextField jTextFieldSignKeyUUID = null;
+	private JTextField jTextFieldSignKeyFilename = null;
 
 	private JRadioButton jRadioButtonSignKeyUpdate = null;
 
 	private JButton jButtonCreateSignKey = null;
 
+	private JRadioButton jRadioButtonKnoppix = null;
+
+	private JLabel jLabel20 = null;
+
+	private JTextField jTextFieldUserName = null;
+
+	private JButton jButtonSetupUser = null;
+
 
 	/**
 	 * This method initializes jJMenuBar	
@@ -820,6 +828,7 @@ public class ClientAdmin extends JFrame {
 			jPanelManifest.add(getJTextFieldPlatformManifestUUID(), null);
 			jPanelManifest.add(jLabel15, null);
 			jPanelManifest.add(getJComboBoxPlatformManifestPvaUrl(), null);
+			jPanelManifest.add(getJRadioButtonKnoppix(), null);
 			jPanelManifest.add(getJButtonCreatePlatformManifest(), null);
 			jPanelManifest.add(getJButton5(), null);
 			jPanelManifest.add(getJButton2(), null);
@@ -874,6 +883,14 @@ public class ClientAdmin extends JFrame {
 							System.out.println("Keep current Platform Manifest");
 						}
 					}
+					else {
+						// New
+						System.out.println("Create New Platform Manifest");
+						String result = config.createPlatformManifest();
+						jTextFieldPlatformManifestStatus.setText(result);
+						String uuid = config.getPlatformManifestUUID();
+						jTextFieldPlatformManifestUUID.setText(uuid);
+					}
 					
 				}
 			});
@@ -921,7 +938,7 @@ public class ClientAdmin extends JFrame {
 						if (rc == JOptionPane.YES_OPTION) {
 							// UPDATE
 							System.out.println("Update Runtime Manifest");
-							String result = config.createRuntimeManifest();
+							String result = config.createRuntimeManifest(jRadioButtonKnoppix.isSelected());
 							jTextFieldRuntimeManifestStatus.setText(result);
 							String uuid = config.getRuntimeManifestUUID();
 							jTextFieldRuntimeManifestUUID.setText(uuid);
@@ -931,6 +948,14 @@ public class ClientAdmin extends JFrame {
 							System.out.println("Keep current Runtime Manifest");
 						}
 					}
+					else {
+						// New 
+						System.out.println("Create New Runtime Manifest");
+						String result = config.createRuntimeManifest(jRadioButtonKnoppix.isSelected());
+						jTextFieldRuntimeManifestStatus.setText(result);
+						String uuid = config.getRuntimeManifestUUID();
+						jTextFieldRuntimeManifestUUID.setText(uuid);
+					}
 				}
 			});
 		}
@@ -1176,12 +1201,17 @@ public class ClientAdmin extends JFrame {
 	 */
 	private JPanel getJPanelIdentitySetup() {
 		if (jPanelIdentitySetup == null) {
+			jLabel20 = new JLabel();
+			jLabel20.setText("User");
+			jLabel20.setSize(new Dimension(100, 30));
+			jLabel20.setLocation(new Point(31, 286));
 			jLabel19 = new JLabel();
-			jLabel19.setBounds(new Rectangle(26, 174, 87, 29));
-			jLabel19.setText("UUID");
+			jLabel19.setText("Key Filename");
+			jLabel19.setSize(new Dimension(100, 30));
+			jLabel19.setLocation(new Point(25, 157));
 			jLabel18 = new JLabel();
-			jLabel18.setBounds(new Rectangle(17, 123, 340, 35));
-			jLabel18.setText("Create Key");
+			jLabel18.setBounds(new Rectangle(16, 107, 341, 35));
+			jLabel18.setText("Create Key and Setup for user");
 			jLabel17 = new JLabel();
 			jLabel17.setBounds(new Rectangle(21, 15, 331, 28));
 			jLabel17.setText("Take Ownership");
@@ -1191,9 +1221,12 @@ public class ClientAdmin extends JFrame {
 			jPanelIdentitySetup.add(getJButtonInvokeTPMM(), null);
 			jPanelIdentitySetup.add(jLabel18, null);
 			jPanelIdentitySetup.add(jLabel19, null);
-			jPanelIdentitySetup.add(getJTextFieldSignKeyUUID(), null);
+			jPanelIdentitySetup.add(getJTextFieldSignKeyFilename(), null);
 			jPanelIdentitySetup.add(getJRadioButtonSignKeyUpdate(), null);
 			jPanelIdentitySetup.add(getJButtonCreateSignKey(), null);
+			jPanelIdentitySetup.add(jLabel20, null);
+			jPanelIdentitySetup.add(getJTextFieldUserName(), null);
+			jPanelIdentitySetup.add(getJButtonSetupUser(), null);
 		}
 		return jPanelIdentitySetup;
 	}
@@ -1206,8 +1239,9 @@ public class ClientAdmin extends JFrame {
 	private JButton getJButtonInvokeTPMM() {
 		if (jButtonInvokeTPMM == null) {
 			jButtonInvokeTPMM = new JButton();
-			jButtonInvokeTPMM.setBounds(new Rectangle(31, 61, 298, 39));
 			jButtonInvokeTPMM.setText("Invoke TPM Manager");
+			jButtonInvokeTPMM.setSize(new Dimension(300, 40));
+			jButtonInvokeTPMM.setLocation(new Point(34, 51));
 			jButtonInvokeTPMM.addActionListener(new java.awt.event.ActionListener() {
 				public void actionPerformed(java.awt.event.ActionEvent e) {
 					
@@ -1227,16 +1261,16 @@ public class ClientAdmin extends JFrame {
 	}
 
 	/**
-	 * This method initializes jTextFieldSignKeyUUID	
+	 * This method initializes jTextFieldSignKeyFilename	
 	 * 	
 	 * @return javax.swing.JTextField	
 	 */
-	private JTextField getJTextFieldSignKeyUUID() {
-		if (jTextFieldSignKeyUUID == null) {
-			jTextFieldSignKeyUUID = new JTextField();
-			jTextFieldSignKeyUUID.setBounds(new Rectangle(124, 176, 417, 29));
+	private JTextField getJTextFieldSignKeyFilename() {
+		if (jTextFieldSignKeyFilename == null) {
+			jTextFieldSignKeyFilename = new JTextField();
+			jTextFieldSignKeyFilename.setBounds(new Rectangle(130, 158, 417, 29));
 		}
-		return jTextFieldSignKeyUUID;
+		return jTextFieldSignKeyFilename;
 	}
 
 	/**
@@ -1247,7 +1281,9 @@ public class ClientAdmin extends JFrame {
 	private JRadioButton getJRadioButtonSignKeyUpdate() {
 		if (jRadioButtonSignKeyUpdate == null) {
 			jRadioButtonSignKeyUpdate = new JRadioButton();
-			jRadioButtonSignKeyUpdate.setBounds(new Rectangle(35, 214, 186, 21));
+			jRadioButtonSignKeyUpdate.setBounds(new Rectangle(38, 197, 186, 21));
+			jRadioButtonSignKeyUpdate.setSelected(true);
+			jRadioButtonSignKeyUpdate.setEnabled(false);
 			jRadioButtonSignKeyUpdate.setText("Update");
 		}
 		return jRadioButtonSignKeyUpdate;
@@ -1261,11 +1297,12 @@ public class ClientAdmin extends JFrame {
 	private JButton getJButtonCreateSignKey() {
 		if (jButtonCreateSignKey == null) {
 			jButtonCreateSignKey = new JButton();
-			jButtonCreateSignKey.setBounds(new Rectangle(25, 245, 306, 41));
-			jButtonCreateSignKey.setText("Create Key for Quote (Atetstation)");
+			jButtonCreateSignKey.setText("Create Key for Quote (Attestation)");
+			jButtonCreateSignKey.setSize(new Dimension(300, 40));
+			jButtonCreateSignKey.setLocation(new Point(26, 224));
 			jButtonCreateSignKey.addActionListener(new java.awt.event.ActionListener() {
 				public void actionPerformed(java.awt.event.ActionEvent e) {					
-					config.setSignKeyUUID(jTextFieldSignKeyUUID.getText());
+					config.setSignKeyFilename(jTextFieldSignKeyFilename.getText());
 					if (jRadioButtonSignKeyUpdate.isEnabled()) {
 						config.setSignKeyUpdateFlag(true);
 					}
@@ -1287,6 +1324,66 @@ public class ClientAdmin extends JFrame {
 		return jButtonCreateSignKey;
 	}
 
+	/**
+	 * This method initializes jRadioButtonKnoppix	
+	 * 	
+	 * @return javax.swing.JRadioButton	
+	 */
+	private JRadioButton getJRadioButtonKnoppix() {
+		if (jRadioButtonKnoppix == null) {
+			jRadioButtonKnoppix = new JRadioButton();
+			jRadioButtonKnoppix.setText("Knopppix");
+			jRadioButtonKnoppix.setSize(new Dimension(100, 21));
+			jRadioButtonKnoppix.setSelected(true);
+			jRadioButtonKnoppix.setLocation(new Point(279, 171));
+		}
+		return jRadioButtonKnoppix;
+	}
+
+	/**
+	 * This method initializes jTextFieldUserName	
+	 * 	
+	 * @return javax.swing.JTextField	
+	 */
+	private JTextField getJTextFieldUserName() {
+		if (jTextFieldUserName == null) {
+			jTextFieldUserName = new JTextField();
+			jTextFieldUserName.setBounds(new Rectangle(137, 287, 267, 27));
+		}
+		return jTextFieldUserName;
+	}
+
+	/**
+	 * This method initializes jButtonSetupUser	
+	 * 	
+	 * @return javax.swing.JButton	
+	 */
+	private JButton getJButtonSetupUser() {
+		if (jButtonSetupUser == null) {
+			jButtonSetupUser = new JButton();
+			jButtonSetupUser.setText("Setup local settings for User ");
+			jButtonSetupUser.setSize(new Dimension(300, 40));
+			jButtonSetupUser.setLocation(new Point(27, 332));
+			jButtonSetupUser.addActionListener(new java.awt.event.ActionListener() {
+				public void actionPerformed(java.awt.event.ActionEvent e) {
+					/* Setup User */
+					if (config.setupUser(jTextFieldUserName.getText()) == false) {
+						JOptionPane.showConfirmDialog(
+								getParent() , 
+								config.getErrorMessage(),
+								"Error", 
+								JOptionPane.DEFAULT_OPTION);//YES_OPTION);
+
+						// TODO  error dialog
+					}
+					
+
+				}
+			});
+		}
+		return jButtonSetupUser;
+	}
+
 	/**
 	 * @param args
 	 */
@@ -1313,14 +1410,14 @@ public class ClientAdmin extends JFrame {
 			//String cpFilename="sampledata/knoppix511tcg.tm3"; // TODO
 			//String cpFilename="../openpts-testsuite/sandbox/knoppix511tcg.tm3"; // TODO
 			//String cpFilename="/opt/OpenPlatformTrustServices/tcdemo/sample.tm3";
-			String cpFilename = config.getTM3Filename();
-			BuilderTM3 cpBuilderTM3 = new BuilderTM3(new File(cpFilename));
-			treemapComponentRoot = cpBuilderTM3.getRoot();
-			cpBuilderTM3.setValues("CVSS");
+			//String cpFilename = config.getTM3Filename();
+			//BuilderTM3 cpBuilderTM3 = new BuilderTM3(new File(cpFilename));
+			//treemapComponentRoot = cpBuilderTM3.getRoot();
+			//cpBuilderTM3.setValues("CVSS");
 			//cpBuilderTM3.setWeights("LOC");
-			cpBuilderTM3.setWeights("Dependency");
+			//cpBuilderTM3.setWeights("Dependency");
 		
-			treeModelCP = new DefaultTreeModel(treemapComponentRoot);
+			//treeModelCP = new DefaultTreeModel(treemapComponentRoot);
 				
 			
 			
@@ -1424,7 +1521,8 @@ public class ClientAdmin extends JFrame {
 		this.jTextFieldRuntimeManifestUUID.setText(config.getRuntimeManifestUUID());
 		
 		/* Panel - Identity Setup */
-		this.jTextFieldSignKeyUUID.setText(config.getSignKeyUUID());
+		this.jTextFieldSignKeyFilename.setText(config.getSignKeyFilename());
+		this.jTextFieldUserName.setText(config.getUserName());
 		/* Panel - Service */
 		updateService();		
 	}
